==> node-babel7_7.17.11%2B~cs214.263.190.orig.tar.xz: babel-7.17.11/packages/babel-helper-optimise-call-expression/test/index.js <==
import { parse } from "@babel/parser";
import * as t from "@babel/types";

import _generator from "@babel/generator";
import _optimizeCallExpression from "../lib/index.js";
const generator = _generator.default;
const optimizeCallExpression = _optimizeCallExpression.default;

function transformInput(input, thisIdentifier) {
  const ast = parse(input);
  const callExpression = ast.program.body[0].expression;
  return generator(
    optimizeCallExpression(
      callExpression.callee,
      thisIdentifier
        ? t.identifier(thisIdentifier)
        : callExpression.callee.object,
      callExpression.arguments,
      callExpression.type === "OptionalCallExpression",
    ),
  ).code;
}

describe("@babel/helper-optimise-call-expression", () => {
  test("optimizeCallExpression should work when thisNode is implied from callee", () => {
    expect(transformInput("a.b(...arguments)")).toMatchInlineSnapshot(
      `"a.b.apply(a, arguments)"`,
    );
    expect(transformInput("a[b](...arguments)")).toMatchInlineSnapshot(
      `"a[b].apply(a, arguments)"`,
    );
    expect(transformInput("a.b?.(...arguments)")).toMatchInlineSnapshot(
      `"a.b?.apply(a, arguments)"`,
    );
    expect(transformInput("a[b]?.(...arguments)")).toMatchInlineSnapshot(
      `"a[b]?.apply(a, arguments)"`,
    );

    expect(transformInput("a.b(...args)")).toMatchInlineSnapshot(
      `"a.b.call(a, ...args)"`,
    );
    expect(transformInput("a[b](...args)")).toMatchInlineSnapshot(
      `"a[b].call(a, ...args)"`,
    );
    expect(transformInput("a.b?.(...args)")).toMatchInlineSnapshot(
      `"a.b?.call(a, ...args)"`,
    );
    expect(transformInput("a[b]?.(...args)")).toMatchInlineSnapshot(
      `"a[b]?.call(a, ...args)"`,
    );

    expect(transformInput("a.b(arg1, arg2)")).toMatchInlineSnapshot(
      `"a.b.call(a, arg1, arg2)"`,
    );
    expect(transformInput("a[b](arg1, arg2)")).toMatchInlineSnapshot(
      `"a[b].call(a, arg1, arg2)"`,
    );
    expect(transformInput("a.b?.(arg1, arg2)")).toMatchInlineSnapshot(
      `"a.b?.call(a, arg1, arg2)"`,
    );
    expect(transformInput("a[b]?.(arg1, arg2)")).toMatchInlineSnapshot(
      `"a[b]?.call(a, arg1, arg2)"`,
    );
  });

  test("optimizeCallExpression should work when thisNode is provided", () => {
    expect(transformInput("a.b(...arguments)", "c")).toMatchInlineSnapshot(
      `"a.b.apply(c, arguments)"`,
    );
    expect(transformInput("a[b](...arguments)", "c")).toMatchInlineSnapshot(
      `"a[b].apply(c, arguments)"`,
    );
    expect(transformInput("a.b?.(...arguments)", "c")).toMatchInlineSnapshot(
      `"a.b?.apply(c, arguments)"`,
    );
    expect(transformInput("a[b]?.(...arguments)", "c")).toMatchInlineSnapshot(
      `"a[b]?.apply(c, arguments)"`,
    );

    expect(transformInput("a.b(...args)", "c")).toMatchInlineSnapshot(
      `"a.b.call(c, ...args)"`,
    );
    expect(transformInput("a[b](...args)", "c")).toMatchInlineSnapshot(
      `"a[b].call(c, ...args)"`,
    );
    expect(transformInput("a.b?.(...args)", "c")).toMatchInlineSnapshot(
      `"a.b?.call(c, ...args)"`,
    );
    expect(transformInput("a[b]?.(...args)", "c")).toMatchInlineSnapshot(
      `"a[b]?.call(c, ...args)"`,
    );

    expect(transformInput("a.b(arg1, arg2)", "c")).toMatchInlineSnapshot(
      `"a.b.call(c, arg1, arg2)"`,
    );
    expect(transformInput("a[b](arg1, arg2)", "c")).toMatchInlineSnapshot(
      `"a[b].call(c, arg1, arg2)"`,
    );
    expect(transformInput("a.b?.(arg1, arg2)", "c")).toMatchInlineSnapshot(
      `"a.b?.call(c, arg1, arg2)"`,
    );
    expect(transformInput("a[b]?.(arg1, arg2)", "c")).toMatchInlineSnapshot(
      `"a[b]?.call(c, arg1, arg2)"`,
    );
  });
});

==> node-babel7_7.18.9%2B~cs214.249.185.orig.tar.xz: babel-7.18.9/packages/babel-helper-optimise-call-expression/test/index.js <==
import { parse } from "@babel/parser";
import * as t from "@babel/types";

import _generator from "@babel/generator";
import _optimizeCallExpression from "../lib/index.js";
const generator = _generator.default || _generator;
const optimizeCallExpression =
  _optimizeCallExpression.default || _optimizeCallExpression;

function transformInput(input, thisIdentifier) {
  const ast = parse(input);
  const callExpression = ast.program.body[0].expression;
  return generator(
    optimizeCallExpression(
      callExpression.callee,
      thisIdentifier
        ? t.identifier(thisIdentifier)
        : callExpression.callee.object,
      callExpression.arguments,
      callExpression.type === "OptionalCallExpression",
    ),
  ).code;
}

describe("@babel/helper-optimise-call-expression", () => {
  test("optimizeCallExpression should work when thisNode is implied from callee", () => {
    expect(transformInput("a.b(...arguments)")).toMatchInlineSnapshot(
      `"a.b.apply(a, arguments)"`,
    );
    expect(transformInput("a[b](...arguments)")).toMatchInlineSnapshot(
      `"a[b].apply(a, arguments)"`,
    );
    expect(transformInput("a.b?.(...arguments)")).toMatchInlineSnapshot(
      `"a.b?.apply(a, arguments)"`,
    );
    expect(transformInput("a[b]?.(...arguments)")).toMatchInlineSnapshot(
      `"a[b]?.apply(a, arguments)"`,
    );

    expect(transformInput("a.b(...args)")).toMatchInlineSnapshot(
      `"a.b.call(a, ...args)"`,
    );
    expect(transformInput("a[b](...args)")).toMatchInlineSnapshot(
      `"a[b].call(a, ...args)"`,
    );
    expect(transformInput("a.b?.(...args)")).toMatchInlineSnapshot(
      `"a.b?.call(a, ...args)"`,
    );
    expect(transformInput("a[b]?.(...args)")).toMatchInlineSnapshot(
      `"a[b]?.call(a, ...args)"`,
    );

    expect(transformInput("a.b(arg1, arg2)")).toMatchInlineSnapshot(
      `"a.b.call(a, arg1, arg2)"`,
    );
    expect(transformInput("a[b](arg1, arg2)")).toMatchInlineSnapshot(
      `"a[b].call(a, arg1, arg2)"`,
    );
    expect(transformInput("a.b?.(arg1, arg2)")).toMatchInlineSnapshot(
      `"a.b?.call(a, arg1, arg2)"`,
    );
    expect(transformInput("a[b]?.(arg1, arg2)")).toMatchInlineSnapshot(
      `"a[b]?.call(a, arg1, arg2)"`,
    );
  });

  test("optimizeCallExpression should work when thisNode is provided", () => {
    expect(transformInput("a.b(...arguments)", "c")).toMatchInlineSnapshot(
      `"a.b.apply(c, arguments)"`,
    );
    expect(transformInput("a[b](...arguments)", "c")).toMatchInlineSnapshot(
      `"a[b].apply(c, arguments)"`,
    );
    expect(transformInput("a.b?.(...arguments)", "c")).toMatchInlineSnapshot(
      `"a.b?.apply(c, arguments)"`,
    );
    expect(transformInput("a[b]?.(...arguments)", "c")).toMatchInlineSnapshot(
      `"a[b]?.apply(c, arguments)"`,
    );

    expect(transformInput("a.b(...args)", "c")).toMatchInlineSnapshot(
      `"a.b.call(c, ...args)"`,
    );
    expect(transformInput("a[b](...args)", "c")).toMatchInlineSnapshot(
      `"a[b].call(c, ...args)"`,
    );
    expect(transformInput("a.b?.(...args)", "c")).toMatchInlineSnapshot(
      `"a.b?.call(c, ...args)"`,
    );
    expect(transformInput("a[b]?.(...args)", "c")).toMatchInlineSnapshot(
      `"a[b]?.call(c, ...args)"`,
    );

    expect(transformInput("a.b(arg1, arg2)", "c")).toMatchInlineSnapshot(
      `"a.b.call(c, arg1, arg2)"`,
    );
    expect(transformInput("a[b](arg1, arg2)", "c")).toMatchInlineSnapshot(
      `"a[b].call(c, arg1, arg2)"`,
    );
    expect(transformInput("a.b?.(arg1, arg2)", "c")).toMatchInlineSnapshot(
      `"a.b?.call(c, arg1, arg2)"`,
    );
    expect(transformInput("a[b]?.(arg1, arg2)", "c")).toMatchInlineSnapshot(
      `"a[b]?.call(c, arg1, arg2)"`,
    );
  });
});
